@@ -88,9 +88,10 @@ _apply_operation_specific = _get_operation_list()
 
 class _WhiteBlackContainer:
 
-    def __init__(self, white_op=None, black_op=None):
+    def __init__(self, white_op=None, black_op=None, verbose=0):
         self._white_op = white_op
         self._black_op = black_op
+        self.verbose = verbose
 
     def is_allowed(self, node_type):
         """
@@ -126,12 +127,12 @@ class RawModelContainerNode(_WhiteBlackContainer):
     framework can work with models generated by different tools.
     """
 
-    def __init__(self, raw_model, white_op=None, black_op=None):
+    def __init__(self, raw_model, white_op=None, black_op=None, verbose=0):
         """
         :param raw_model: *scikit-learn* model to convert
         """
         _WhiteBlackContainer.__init__(
-            self, white_op=white_op, black_op=black_op)
+            self, white_op=white_op, black_op=black_op, verbose=verbose)
         self._raw_model = raw_model
 
     @property
@@ -165,9 +166,11 @@ class SklearnModelContainerNode(RawModelContainerNode):
     :class:`Topology <skl2onnx.common._topology.Topology>`.
     """
 
-    def __init__(self, sklearn_model, white_op=None, black_op=None):
+    def __init__(self, sklearn_model, white_op=None, black_op=None,
+                 verbose=0):
         super(SklearnModelContainerNode, self).__init__(
-            sklearn_model, white_op=white_op, black_op=black_op)
+            sklearn_model, white_op=white_op, black_op=black_op,
+            verbose=verbose)
         # Scikit-learn models have no input and output specified,
         # so we create them and store them in this container.
         self._inputs = []
@@ -202,7 +205,7 @@ class ModelComponentContainer(ModelContainer, _WhiteBlackContainer):
     """
 
     def __init__(self, target_opset, options=None, registered_models=None,
-                 white_op=None, black_op=None):
+                 white_op=None, black_op=None, verbose=0):
         """
         :param target_opset: number, for example, 7 for *ONNX 1.2*, and
                              8 for *ONNX 1.3*.
@@ -212,9 +215,10 @@ class ModelComponentContainer(ModelContainer, _WhiteBlackContainer):
             while converting a pipeline, if empty, all are allowed
         :param black_op: black list of ONNX nodes allowed
             while converting a pipeline, if empty, none are blacklisted
+        :param verbose: display information while converting
         """
         _WhiteBlackContainer.__init__(
-            self, white_op=white_op, black_op=black_op)
+            self, white_op=white_op, black_op=black_op, verbose=verbose)
         # Inputs of ONNX graph. They are ValueInfoProto in ONNX.
         self.inputs = []
         # Outputs of ONNX graph. They are ValueInfoProto in ONNX.
@@ -349,7 +353,7 @@ class ModelComponentContainer(ModelContainer, _WhiteBlackContainer):
         elif shape is None and isinstance(
                 content, (np.float32, np.float64, np.int32,
                           np.int64, float, np.int8, np.uint8,
-                          np.bool_)):
+                          np.bool_, np.str_, str)):
             tensor = make_tensor(name, onnx_type, [], [content])
         elif (SparseTensorProto is not None and
                 isinstance(content, SparseTensorProto)):
@@ -735,14 +739,22 @@ class ModelComponentContainer(ModelContainer, _WhiteBlackContainer):
         if len(missing_ops) > 0:
             def nstr(name):
                 if name in order:
-                    return "%s(%d)" % (name, order[name])
+                    return "%s#%d" % (name, order[name])
                 return name
-            rows = ["%s (%s) -> (%s)" % (
+            rows = ["%s(%s) -> [%s]" % (
                 n.name or n.op_type,
                 ', '.join(map(nstr, n.input)),
                 ', '.join(n.output))
                 for n in missing_ops]
             rows.insert(0, "")
+            rows.append("--")
+            rows.append("--all-nodes--")
+            rows.append("--")
+            rows.extend("%s(%s) -> [%s]" % (
+                n.name or n.op_type,
+                ', '.join(map(nstr, n.input)),
+                ', '.join(n.output))
+                for n in self.nodes)
             raise RuntimeError(
                 "After %d iterations for %d nodes, still unable "
                 "to sort names %r. The graph may be disconnected. "
