@@ -80,8 +80,8 @@ def _samme_r_proba(scope, container, proba_name, n_classes, dtype, pdtype):
 
     apply_clip(
         scope, proba_name, clipped_proba_name, container,
-        operator_name=scope.get_unique_operator_name('Clip'),
-        min=float(cst_min))
+        operator_name=scope.get_unique_operator_name('ClipAda'),
+        min=dtype(cst_min))
     container.add_node(
         'Log', clipped_proba_name, log_proba_name,
         name=scope.get_unique_operator_name('Log'))
